/**
 * @(#)CivLogProperties.java
 *
 * Created on July 28, 2000
 */


/**
 *
 * @author  Michael Grundel <michael42@grundel.de>
 * @version 0.02
 */

/**
    *******************************************************************
 CivLog - Copyleft (C) 2000 - Wong Teck Meng
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
**********************************************************************/

package org.freeciv.civlog;

import java.util.Properties;
import java.io.*;


/**
 * CLProperties handles custom Properties
 *
 * The following properties are set:
 *   civlog.dynamicRescale=false/
 */
public class CLProperties
{
    private static final String propFile = ".civlogProperties";
    private static Properties prop = null;

    static {
        Debug.trace ("CLProperties: static initializer");
        if (! loadProperties())
            Debug.trace("CLProperties: static initializer: Error loading Properties");
    }

    /* System properties
      Key                                Meaning
      "os.arch"                          Operating system architecture
      "os.name"                          Operating system name
      "os.version"                       Operating system version
      "path.separator"                   Path separator (for example, ":")
      "user.dir"                         User's current working directory
      "user.home"                        User home directory
      "user.name"                        User account name
    */

    /** find out where the properties are saved
        int case user.home is not available on some platform: add code here
    */
    public static String getProperty (String p)
    {
        return prop.getProperty (p);
    }

    public static void setProperty (String k, String v)
    {
        Debug.trace("CLProperties: setProperty("+k+", "+v+")");
        prop.setProperty (k, v);
        saveProperties();
    }

    private static String getPropertyPath ()
    {
        return  (System.getProperty("user.home") +
                 System.getProperty("file.separator") + propFile);
    }

    /**
     * Unsets (clears) a property.
     * @param name The property
     */

    public static void unsetProperty(String name)
    {
        prop.remove(name);
    }

    // load the propertiesFile, called int static initializer
    private static boolean loadProperties ()
    {
        Debug.trace ("CLProperties: loadProperties()");
        String propFileName = getPropertyPath();
        if (propFileName == null)
            return false;

        Properties props = new Properties ();
        // load custom properties from file into it
        try
        {
            props.load (new BufferedInputStream (new FileInputStream (propFileName)));
        }
        catch (java.io.FileNotFoundException ex)
        {
            Debug.trace ("Error (CLProperties): loadProperties, FileNotFoundException\n"+
                         "The property-file ("+propFileName+") was not found.\n"+
                         "If this is the first time you start CivLog this is ok and\n"+
                         "it will be created for you.\n"+
                         "If this happens often, please contact the authors, you found a bug!");
        }
        catch (java.io.IOException ex)
        {
            Debug.trace ("Error (CLProperties): loadProperties, IOException");
        }
        prop = props;
        return true;
    } // loadProperties


    /** saves properties in a property file */
    public static boolean saveProperties ()
    {
        Debug.trace ("CLProperties: saveProperties()");
        if (!createPropertyFile (prop))
        {
            Debug.trace ("Error (CLProperties): cannot save properties, createPropertyFile returns false");
            return false;
        }
        return true;
    }

    // creates the propertyFile with the properties specified in newProp
    static boolean createPropertyFile (Properties newProp)
    {
        String propDir = getPropertyPath();

        FileOutputStream defaultsOut = null;
        try
        {
            defaultsOut = new FileOutputStream(propDir);
        }
        catch (Exception ex)
        {
            Debug.trace ("Error (CLProperties): could not open "+propDir);
            return false;
        }

        newProp.save (defaultsOut, "---=== CivLog Properties ===---");
        try
        {
            defaultsOut.close();
        }
        catch  (Exception ex)
        {
            Debug.trace ("Error (CLProperties): could not close file "+propDir);
            return false;
        }

        if (loadProperties() != true)
        {
            Debug.trace ("Error (CLProperties): loading of Properties failed after writing.");
            return false;
        }

        return true;
    }

}
