/**
 * @(#)ColorManager.java - Is used to store the color theme for
 *     each players
 *
 * Created on September 7, 2000, 9:05 PM
 */


/**
 *
 * @author  Raimar Falke <rf13@inf.tu-dresden.de>
 * @version 0.01
 */

/**
   ********************************************************************
 CivLog - Copyleft (C) 2000 - Wong Teck Meng
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
**********************************************************************
                                                                      */

package org.freeciv.civlog;

import java.awt.Color;

public class ColorManager
{
    public static final int THEME_WHITE = 0;
    public static final int THEME_BLACK = 1;

    static Color[] GraphBackgroundColor = { Color.white, Color.black };
    static Color[] AverageLineColor = { Color.orange.darker(), Color.cyan.darker() };
    static Color[] AverageLabelColor = { Color.black, Color.white };
    static Color[] GridColor = { Color.lightGray, Color.lightGray };
    static Color[] MaxPointColor = { Color.red, Color.cyan };
    static Color[] MaxLabelColor = { Color.black, Color.white };
    static Color[] MinPointColor = { Color.red, Color.pink };
    static Color[] MinLabelColor = { Color.black, Color.white };
    static Color[] XAxisLabelColor = { Color.black, Color.white };
    static Color[] YAxisLabelColor = { Color.black, Color.white };
    static Color[] XAxisNumbersColor = { Color.black, Color.white };
    static Color[] YAxisNumbersColor = { Color.black, Color.white };

    /** colors for the lines use to draw graph */
    private static Color playerColors[] = null;

    /** current color theme to use */
    private static int theme = 0;

    static
    {
        /** hues for HSB model */
        /** 330, 30, 75, 120, 180, 240, 300 degree for hue */
        float hues[] = {11f/12f, 1f/12f,
                        5f/24f, 2f/6f, 3f/6f, 4f/6f, 5f/6f};
        /** X 360 for actual hue no. */

        playerColors=new Color[hues.length*2];

        int i=0;

        for(int j=0; j<2; j++)
        {
            float saturation = -1f, brightness =- 1f;

            switch(j)
            {
                case 0:
                    saturation = 1f;
                    brightness = 1f;
                    break;
                case 1:
                    saturation = 0.6f;
                    brightness = 0.7f;
                    break;
                default:
                    throw new InternalError();
            }

            //Debug.trace("saturation="+saturation);
            //Debug.trace("brightness="+brightness);

            for(int hueIndex = 0;
                    hueIndex < hues.length;
                    hueIndex++)
            {
                float hue = hues[hueIndex];

                //Debug.trace("hue="+hue);

                playerColors[i] = new Color (Color.HSBtoRGB (hue, saturation,
                                             brightness));
                //Debug.trace("Set "+i+" to "+playerColors[i]);
                i++;
            }
        }
    };


    public static void setTheme ( int theTheme )
    {
        /** if theTheme isn't out of range */
        if ( !(theTheme > GraphBackgroundColor.length) )
            theme = theTheme;
    }

    public static int getTheme ()
    {
        return theme;
    }

    public static Color getColorForPlayer(int player)
    {
        return playerColors[player%playerColors.length];
    }

    public static Color getGraphBackgroundColor ()
    {
        return GraphBackgroundColor[theme];
    }

    public static Color getAverageLabelColor ()
    {
        return AverageLabelColor[theme];
    }

    public static Color getAverageLineColor ()
    {
        return AverageLineColor[theme];
    }

    public static Color getGridColor ()
    {
        return GridColor[theme];
    }

    public static Color getMaxPointColor ()
    {
        return MaxPointColor[theme];
    }

    public static Color getMaxLabelColor ()
    {
        return MaxLabelColor[theme];
    }

    public static Color getMinPointColor ()
    {
        return MinPointColor[theme];
    }

    public static Color getMinLabelColor ()
    {
        return MinLabelColor[theme];
    }

    public static Color getXAxisLabelColor ()
    {
        return XAxisLabelColor[theme];
    }

    public static Color getYAxisLabelColor ()
    {
        return YAxisLabelColor[theme];
    }

    public static Color getXAxisNumbersColor ()
    {
        return XAxisNumbersColor[theme];
    }

    public static Color getYAxisNumbersColor ()
    {
        return YAxisNumbersColor[theme];
    }
}
// End of ColorManager.java
