/*
 * @(#)GraphList.java - Container in the center, holds all the Graph-Objects
 *
 *
 * Created on August 25, 2000
 */


/**
 *
 * @author  Michael Grundel <michael42@grundel.de>
 * @author  Raimar Falke <rf13@inf.tu-dresden.de>
 * @version 0.03
 */

/**
   ********************************************************************
 CivLog - Copyleft (C) 2000 - Wong Teck Meng
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
*********************************************************************
                                                                      */

package org.freeciv.civlog.gui;

import org.freeciv.civlog.Debug;
import org.freeciv.civlog.data.Score;
import org.freeciv.civlog.FreecivConstants;

import java.awt.*;
import java.util.*;

public class GraphList
            extends javax.swing.JPanel
            implements ViewChangeListener
{
    private View view;
    private Score score;
    private Graph[] graphs;

    public GraphList ()
    {
        setLayout(new GridLayout(0,1)); // 1 column, 0 rows = as many as needed
        setVisible(true);
    }

    public void viewChanged(ViewChangeEvent evt)
    {
        if(evt.getCode()!=ViewChangeEvent.C_DATA_TYPE_SELECTION)
            return;

        if(evt.getBool())
            addDataType(evt.getDataTypeOrPlayer());
        else
            removeDataType(evt.getDataTypeOrPlayer());
    }

    public void init(Score score, View view)
    {
        this.score = score;
        this.view = view;

        /** create Graph-Objects for all data types, so that they can
         *  be displayed quickly
         */
        removeAllGraphs();
        graphs = new Graph[FreecivConstants.NUMBER_OF_DATA_TYPES];
        for (int i = 0; i < graphs.length; i++)
        {
            graphs[i] = new Graph (score, view, i);
        }
        view.addViewChangeListener(this);
    }

    /**
     * Tries to add a cached Graph object to the center. If it already
     * is in there, it will not be added.
     */
    private void addDataType(int dataType)
    {
        Debug.trace("GraphList: adding "+dataType);
        add(graphs[dataType]);
        getLayout().layoutContainer(this);
        repaint();
    }

    /**
     * Tries to remove a cached Graph object from the center. If it is
     * not in there, nothing will happen.
     */
    private void removeDataType(int dataType)
    {
        Debug.trace("GraphList: removing "+dataType);
        remove(graphs[dataType]);
        getLayout().layoutContainer(this);
        repaint();
    }

    private void removeAllGraphs()
    {
        removeAll();
    }

    public void synchronizeWithView()
    {
        removeAllGraphs();
        for(int i=0;i<graphs.length;i++)
        {
            if(view.isDataTypeSelected(i))
                addDataType(i);
        }
    }
}
// End of GraphList.java
