/**
 * @(#)RecentMenu.java - A recent menu
 *
 *
 * Created on September 11, 2000, 11:27AM
 */


/**
 *
 * @author  furyhawk <lookmeow@magix.com.sg>
 * @version 0.01
 */

/*
 * Copyright (C) 2000 Romain Guy
 * guy.romain@bigfoot.com
 * www.jext.org
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.freeciv.civlog.gui;

import java.io.File;

import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuItem;

import org.freeciv.civlog.CLProperties;
import org.freeciv.civlog.Utilities;

public class RecentMenu
{
    private JMenu recentMenu;
    private JFrame parent;

    private int maxRecent;
    private String recent[] = new String[8];

    public RecentMenu(JFrame parent, JMenu recentMenu)
    {
        this.parent = parent;
        this.recentMenu = recentMenu;
    }

    /**
     * Cleans recent menu.
     */

    public void removeRecent()
    {
        recentMenu.removeAll();

        for (int i = 0; i < maxRecent; i++)
        {
            String prop = CLProperties.getProperty("recent." + i);
            if (prop != null && !prop.equals(""))
                CLProperties.unsetProperty("recent." + i);
            recent[i] = null;
        }

        JMenuItem nothing = new JMenuItem(CLProperties.getProperty("norecent"));
        nothing.setEnabled(false);
        recentMenu.add(nothing);
        //CivLog.recentChanged(parent);
    }

    /**
     * Creates the recent menu from an array of <code>String</code>
     * containing paths to the most recently opened files.
     * @param mnu The menu where to put last opened files
     */

    public void createRecent()
    {
        try
        {
            maxRecent = Integer.parseInt(CLProperties.getProperty("max.recent"));
        }
        catch (NumberFormatException nf)
        {
            maxRecent = 8;
        }

        String[] _tmp = recent;
        recent = new String[maxRecent];

        for (int i = 0; i < _tmp.length; i++)
        {
            if (i == recent.length)
                break;
            recent[i] = _tmp[i];
        }

        boolean empty = true;
        recentMenu.removeAll();

        for (int i = 0; i < maxRecent; i++)
        {
            recent[i] = CLProperties.getProperty("recent." + i);

            if (recent[i] != null && !recent[i].equals("") && (new File(recent[i])).exists())
            {
                JMenuItem recentItem = new JMenuItem(
                                           Utilities.getShortStringOf(recent[i], 70));
                recentItem.setActionCommand(recent[i]);
                //recentItem.addActionListener(new OpenRecent());
                recentMenu.add(recentItem);
                empty = false;
            }
            else
                CLProperties.unsetProperty("recent." + i);
        }

        if (empty)
        {
            JMenuItem nothing = new JMenuItem(CLProperties.getProperty("editor.norecent"));
            nothing.setEnabled(false);
            recentMenu.add(nothing);
        }
    }

    /**
     * Add an item to the recent menu.
     * @param file The path of the file to be added
     */

    public void saveRecent(String file)
    {
        if (file == null)
            return ;

        for (int i = 0; i < maxRecent; i++)
            if (file.equals(recent[i])) return ;
        for (int i = maxRecent - 1; i > 0; i--)
        {
            recent[i] = recent[i - 1];
            if (recent[i] != null && !recent[i].equals(""))
                CLProperties.setProperty("recent." + i, recent[i]);
        }

        recent[0] = file;
        CLProperties.setProperty("recent.0", file);
        createRecent();

        //CivLog.recentChanged(parent);
    }



}

// End of RecentMenu.java
